@@ -3,16 +3,17 @@ import configparser
 import json
 import os
 import sys
+from typing import Dict
 
 import deltachat.const
 from deltachat import Account, events
 from deltachat.tracker import ConfigureTracker
 
+from . import APP_NAME
 from .event import AccountPlugin
 from .oauth2 import get_authz_code, is_oauth2
 from .ui import CursedDelta
 
-app_name = "Cursed Delta"
 default_theme = {
     "background": ["", "", "", "", "g11"],
     "status_bar": ["", "", "", "white", "g23"],
@@ -68,51 +69,51 @@ default_keymap = {
 }
 
 
-def get_theme():
+def get_theme() -> dict:
     file_name = "theme.json"
     themes = [
         "curseddelta-" + file_name,
-        "{}/.curseddelta/{}".format(os.path.expanduser("~"), file_name),
+        f"{os.path.expanduser('~')}/.curseddelta/{file_name}",
         "/etc/curseddelta/" + file_name,
     ]
 
-    for theme in themes:
-        if os.path.isfile(theme):
-            with open(theme) as fd:
+    for path in themes:
+        if os.path.isfile(path):
+            with open(path, encoding="utf-8") as fd:
                 theme = json.load(fd)
             break
     else:
         theme = default_theme
-        with open(themes[1], "w") as fd:
+        with open(themes[1], "w", encoding="utf-8") as fd:
             json.dump(theme, fd, indent=2)
 
     return theme
 
 
-def get_keymap():
+def get_keymap() -> dict:
     file_name = "keymap.json"
     keymaps = [
         "curseddelta-" + file_name,
-        "{}/.curseddelta/{}".format(os.path.expanduser("~"), file_name),
+        f"{os.path.expanduser('~')}/.curseddelta/{file_name}",
         "/etc/curseddelta/" + file_name,
     ]
 
-    for keymap in keymaps:
-        if os.path.isfile(keymap):
-            with open(keymap) as fd:
+    for path in keymaps:
+        if os.path.isfile(path):
+            with open(path, encoding="utf-8") as fd:
                 keymap = json.load(fd)
             break
     else:
         keymap = default_keymap
-        with open(keymaps[1], "w") as fd:
+        with open(keymaps[1], "w", encoding="utf-8") as fd:
             json.dump(keymap, fd, indent=1)
 
     return keymap
 
 
-def get_configuration():
+def get_configuration() -> dict:
     file_name = "curseddelta.conf"
-    home_config = "{}/.{}".format(os.path.expanduser("~"), file_name)
+    home_config = f"{os.path.expanduser('~')}/.{file_name}"
     confPriorityList = [file_name, home_config, "/etc/" + file_name]
 
     cfg = configparser.ConfigParser()
@@ -124,7 +125,7 @@ def get_configuration():
     else:
         cfg.add_section("general")
 
-    cfg_full = {}
+    cfg_full: Dict[str, dict] = {}
     cfg_full["general"] = {}
 
     home = os.path.expanduser("~")
@@ -133,26 +134,15 @@ def get_configuration():
         "account_path", home + "/.curseddelta/account/account.db"
     )
     cfg_gen["notification"] = cfg["general"].getboolean("notification", True)
-    cfg_gen["open_file"] = cfg["general"].getboolean("open_file", True)
+    cfg_gen["open_file"] = (
+        cfg["general"].getboolean("open_file", True) and "DISPLAY" in os.environ
+    )
     cfg_gen["date_format"] = cfg["general"].get("date_format", "%x", raw=True)
 
-    if "DISPLAY" not in os.environ:
-        cfg_gen["notification"] = False
-        cfg_gen["open_file"] = False
-
-    if cfg_gen["notification"]:
-        try:
-            import gi
-
-            gi.require_version("Notify", "0.7")
-            from gi.repository import Notify
-        except:
-            cfg_gen["notification"] = False
-
     return cfg_full
 
 
-def main():
+def main() -> None:
     sys.argv[0] = "curseddelta"
     argv = sys.argv
     app_path = os.path.join(os.path.expanduser("~"), ".curseddelta")
@@ -191,13 +181,13 @@ def main():
         return
 
     if args.show_ffi:
-        log = events.FFIEventLogger(ac, "CursedDelta")
+        log = events.FFIEventLogger(ac)
         ac.add_account_plugin(log)
 
     if not ac.is_configured():
-        assert args.email, (
-            "you must specify --email once" " to configure this database/account"
-        )
+        assert (
+            args.email
+        ), "you must specify --email once to configure this database/account"
         ac.set_config("addr", args.email)
 
         if not args.password and is_oauth2(ac, args.email):
@@ -207,12 +197,12 @@ def main():
 
             flags = ac.get_config("server_flags")
             flags = int(flags) if flags else 0
-            flags |= deltachat.const.DC_LP_AUTH_OAUTH2
+            flags |= deltachat.const.DC_LP_AUTH_OAUTH2  # noqa
             ac.set_config("server_flags", str(flags))
         else:
-            assert args.password, (
-                "you must specify --password once" " to configure this database/account"
-            )
+            assert (
+                args.password
+            ), "you must specify --password once to configure this database/account"
             ac.set_config("mail_pw", args.password)
 
         with ac.temp_plugin(ConfigureTracker(ac)) as tracker:
@@ -229,5 +219,5 @@ def main():
 
     keymap = get_keymap()
     theme = get_theme()
-    CursedDelta(cfg, keymap, theme, app_name, account)
+    CursedDelta(cfg, keymap, theme, APP_NAME, account)
     ac.shutdown()
